Graph

Trait Graph 

pub trait Graph<Node, Cost> {
    // Required methods
    fn neighbors(&self, node: Node, neighbors: &mut Vec<NodeCost<Node, Cost>>);
    fn heuristic(&self, node: Node, goal: Node) -> Cost;
}
Responsible for providing the graph structure for A* search.

Required Methods

fn neighbors(&self, node: Node, neighbors: &mut Vec<NodeCost<Node, Cost>>)

Adds the neighbors of the node with their edge costs to the neighbors buffer.

fn heuristic(&self, node: Node, goal: Node) -> Cost

Estimates the lower limit of the cost from the node to the goal.

Implementors